@@ -1,6 +1,6 @@
 /* qprogram-starter, a program to start programs or commands, with
    the option to log output and errors and to shutdown the system.
- * Copyright (C) 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,12 @@
 #ifndef GUI_H
 #define GUI_H
 
-#include <QtGui>
-#include <QtDBus>
 #include "ui_gui.h"
+#include <QFileDialog>
+#include <QtGlobal>
+#include <QSettings>
+#include <QProcess>
+
 
 class Gui : public QWidget, public Ui::Gui {
      Q_OBJECT // important for creating own singals and slots
@@ -35,8 +38,9 @@ class Gui : public QWidget, public Ui::Gui {
       QProcess       *process1, *process2;
       QDateTime      nextDate, timeInTheFuture;
       double         secondsToTimeInTheFuture;
-      QTextEdit      *hintMsgBox;
-      QString        file;
+      QTextEdit      *hintMsgBox, *logBox1, *logBox2;
+      QString        file, errProcess1, errProcess2,
+                     outputProcess1, outputProcess2;
       QSettings      *settings; 
       QString        program1, program2;
       bool           process2Started;
@@ -58,6 +62,7 @@ class Gui : public QWidget, public Ui::Gui {
       void shutdown_or_message(); //either shuts down the system or shows if the process is finished
       void info_hint();   //shows a InfoMessageBox
       void saveData();
+      void showLogs();
 
      signals:
       void finished();
