@@ -1,6 +1,6 @@
 /* qprogram-starter, a program to start programs or commands, with
    the option to log output and errors and to shutdown the system.
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,8 +15,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include <QApplication>
 #include "gui.h"
+#include <QApplication>
+#include <QTranslator>
+#include <QLibraryInfo>
 
 int main (int argc, char *argv[]){
 
