@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 #ifndef CALENDAR_H
 #define CALENDAR_H
 
-#include <QtGui>
 #include "ui_calendar.h"
+#include <QDate>
 
 class Calendar : public QDialog, public Ui::Calendar {
      Q_OBJECT
@@ -26,6 +26,11 @@ class Calendar : public QDialog, public Ui::Calendar {
     public:
      Calendar(QWidget *parent = 0);
      ~Calendar();
+     QDate setCalendarDate, calendarDate;
+     bool getClosed();
+
+    private:
+     bool isClosed;
 
     private slots:
      void getDate(QDate date);
