@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,20 +16,22 @@
  */
 
 #include "ch_passwd.h"
+#include <QDir>
+#include <QCryptographicHash>
+#include <QDesktopServices>
 
 ChangePassword::ChangePassword(QWidget *parent): QDialog(parent){
 
-	setupUi(this);
+     setupUi(this);
 
-     setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);    //always in front
+     setWindowFlags(Qt::Window);    //always in front
 
 #ifdef Q_OS_WIN32
      file = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf";
-     settings = new QSettings(file, QSettings::NativeFormat);
 #else //!Q_OS_WIN32
      file = QDir::homePath() + "/.qshutdown/qshutdown.conf";
-     settings = new QSettings(file, QSettings::NativeFormat);
 #endif //Q_OS_WIN32
+     settings = new QSettings(file, QSettings::NativeFormat);
 
      if(settings->contains("Password")){
        oldPasswd->setEnabled(true);
