@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,15 +17,18 @@
 #ifndef EDITOR_H
 #define EDITOR_H
 
-#include <QtGui>
 #include "ui_editor.h"
 
+#include <QFile>
+#include <QSettings>
+
 class Editor : public QDialog, public Ui::Editor {
     Q_OBJECT
  
     public:
      Editor(QWidget *parent = 0);
      ~Editor();
+     bool getClosed();
 
     signals:
      void saved();
@@ -33,11 +36,16 @@ class Editor : public QDialog, public Ui::Editor {
      void finishing();
 
     private:
-     QFile *confFile;
+     QFile     *confFile;
+     QSettings *settings;
+     bool      isClosed;
 
     private slots:
      void saveChanges();
 
+    public slots:
+     bool getLockAll();
+
     protected:
      virtual void showEvent(QShowEvent* show_editor);
      virtual void closeEvent(QCloseEvent* window_close);
