@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown the shutdown/reboot/suspend/hibernate
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,31 +16,21 @@
  */
 
 #include "gui.h"
-#include "power.h"
 #include "preferences.h"
 #include "info.h"
 #include "calendar.h"
 #include "passwd.h"
 #include "editor.h"
+#include "about.h"
+#include "power.h"
+#include <QTextStream>
+#include <QTimer>
 
-bool prefClosed = true;
-bool calendarClosed = true;
-bool infoClosed = true;
-bool passwdClosed = true;
-bool editorClosed = true;
+extern bool verbose;
 
-bool timeRunning;
-bool lockMyScreen;
-extern QString fonts; //variable declared in preferences.cpp
-extern int fontS1;    // ""
-extern int fontS2;    // ""
-extern int fontS3;    // ""
-extern QDate setCalendarDate; //variable declared in calendar.cpp
-bool lockAll = false;
+Gui::Gui(){
 
-Gui::Gui(QWidget *parent): QWidget(parent){
-
-	setupUi(this);
+     setupUi(this);
 
      finishedExecuted = false;
      timeRunning = false;
@@ -49,8 +39,6 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      datetime = QDateTime::currentDateTime();
      elapsedTime.start();
 
-     setWindowFlags(Qt::WindowStaysOnTopHint);
-
      minimize = QString(tr("&Minimize"));
      restore = QString(tr("Res&tore"));
 
@@ -58,7 +46,7 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      pref = new Preferences(this);
 
    //CalendarBox
-     calendarBox = new Calendar(this);
+     cal = new Calendar(this);
 
    //InfoMessageBox
      infoBox = new Info(this);
@@ -69,12 +57,6 @@ Gui::Gui(QWidget *parent): QWidget(parent){
    //Editor
      editor = new Editor(this);
 
-   //Changing SizePolicy for Spacers
-     horizontalSpacer1->changeSize(40,45,QSizePolicy::Expanding,QSizePolicy::Expanding);
-     horizontalSpacer3->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
-     horizontalSpacer4->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
-     horizontalSpacer5->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
-
    //Versioning
      QFile versionFile(":version");
      versionFile.open(QIODevice::ReadOnly | QIODevice::Text);
@@ -83,6 +65,9 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      version->setText(string);
      versionFile.close();
 
+   //About
+     about = new About(this);
+
    //TrayIcon
      icon = QIcon(":red_glasses");
      TIcon = new QSystemTrayIcon(this);
@@ -122,7 +107,7 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      menu->addAction(reboot_action);
      menu->addAction(suspend_action);
      menu->addAction(hibernate_action);
-     reset_action->setVisible(false);
+     reset_action->setEnabled(false);
      menu->addSeparator();
      menu->addAction(minimize_restore_action);
      menu->addAction(quit_action);
@@ -133,15 +118,13 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      minim = new QPushButton(this); //to minimize
      minim->setText(tr("&Minimize!"));
      minim->setHidden(true); //not yet visible
-     minim->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+     QSizePolicy sizePolicy6(QSizePolicy::Expanding, QSizePolicy::Preferred);
+     sizePolicy6.setHorizontalStretch(0);
+     sizePolicy6.setVerticalStretch(1);
+     sizePolicy6.setHeightForWidth(ok->sizePolicy().hasHeightForWidth());
+     minim->setSizePolicy(sizePolicy6);
      gridLayout5->addWidget(minim,0,1,3,1);
 
-   //LCD-Anzeige
-     lcd = new QLCDNumber(4, this); //display for countdown
-     lcd->setSegmentStyle(QLCDNumber::Flat);
-     lcd->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-     gridLayout4->addWidget(lcd,0,1,1,1);
-
    //Fonts
      font1 = new QFont;
      font1->setBold(true);
@@ -169,26 +152,32 @@ Gui::Gui(QWidget *parent): QWidget(parent){
        this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason))); //handles systray-symbol
      connect(power_actions, SIGNAL(triggered(QAction*)), this, SLOT(power(QAction*)));
      connect(reset_action, SIGNAL(triggered()), this, SLOT(reset()));
+     connect(action_Reset, SIGNAL(triggered()), this, SLOT(reset()));
      connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
      connect(minimize_restore_action, SIGNAL(triggered()), this, SLOT(tray_actions()));
      connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
+     connect(actionQuit, SIGNAL(triggered()), qApp, SLOT(quit()));
 
+     connect(action_Configure, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref_action, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref, SIGNAL(starting()), ti, SLOT(stop()));
      connect(pref, SIGNAL(finishing()), this, SLOT(warnings_on())); //start the Qtimer ti if timeRunning == false
      connect(pref, SIGNAL(changeFont()), this, SLOT(getFonts()));
      connect(pref, SIGNAL(editConf()), checkPassword, SLOT(show()));  //ask for password when button was pressed at preferences
 
+     connect(action_Info, SIGNAL(triggered()), this, SLOT(setInfoText()));
+     connect(action_Info, SIGNAL(triggered()), infoBox, SLOT(show()));
      connect(info_action, SIGNAL(triggered()), this, SLOT(setInfoText()));
      connect(info_action, SIGNAL(triggered()), infoBox, SLOT(show()));
      connect(infoBox, SIGNAL(starting()), ti, SLOT(stop()));
      connect(infoBox, SIGNAL(finishing()), this, SLOT(warnings_on()));
 
      connect(toolButton, SIGNAL(clicked(bool)), this, SLOT(showCalendarBox()));
-     connect(calendarBox, SIGNAL(aDateWasSet()), this, SLOT(setDate()));
-     connect(calendarBox, SIGNAL(starting()), ti, SLOT(stop()));
-     connect(calendarBox, SIGNAL(finishing()), this, SLOT(warnings_on()));
+     connect(cal, SIGNAL(aDateWasSet()), this, SLOT(setDate()));
+     connect(cal, SIGNAL(starting()), ti, SLOT(stop()));
+     connect(cal, SIGNAL(finishing()), this, SLOT(warnings_on()));
 
+     connect(checkPassword, SIGNAL(success()), pref, SLOT(saveToConfFile()));
      connect(checkPassword, SIGNAL(success()), this, SLOT(showEditor())); //if correct password was entered open editor
      connect(checkPassword, SIGNAL(starting()), ti, SLOT(stop()));
      connect(checkPassword, SIGNAL(finishing()), this, SLOT(warnings_on()));
@@ -196,7 +185,13 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      connect(editor, SIGNAL(saved()), this, SLOT(updateLock()));      //update to see if Lock_all was (de)activated
      connect(editor, SIGNAL(starting()), ti, SLOT(stop()));
      connect(editor, SIGNAL(finishing()), this, SLOT(warnings_on()));
-     connect(editor, SIGNAL(saved()), pref, SLOT(loadSettings()));    //if qshutdown.conf was edited and saved, update pref
+
+     connect(actionLog_file, SIGNAL(toggled(bool)), log_action, SLOT(setChecked(bool)));
+     connect(log_action, SIGNAL(toggled(bool)), actionLog_file, SLOT(setChecked(bool)));
+
+     connect(action_About, SIGNAL(triggered()), about, SLOT(show()));
+
+     connect(actionKeep_window_proportions, SIGNAL(toggled(bool)), this, SLOT(staticProportions(bool)));
 }
 
 Gui::~Gui(){ delete font1; delete font2; delete font3; }
@@ -215,11 +210,12 @@ void Gui::tray_actions(){
 void Gui::setInfoText(){ infoBox->setHtml(information); }
 
 void Gui::warnings_on(){
-     if(prefClosed && calendarClosed && infoClosed && passwdClosed && editorClosed && !timeRunning)
+     if(pref->getClosed() && cal->getClosed() && infoBox->getClosed() && checkPassword->getClosed()
+        && editor->getClosed() && !timeRunning)
        ti->start();
 }
 
-void Gui::setDate(){ toolButton->setText(setCalendarDate.toString(Qt::SystemLocaleShortDate)); }
+void Gui::setDate(){ toolButton->setText(cal->setCalendarDate.toString(Qt::SystemLocaleShortDate)); }
 
 void Gui::center(){
      QDesktopWidget *desktop = qApp->desktop();
@@ -271,8 +267,15 @@ void Gui::power(QAction *action){
 
 void Gui::showW(){
      if(warnings->isChecked()){ //warnings is checked
-       showRunningProgram();
-       minimize_restore_action->setText(minimize);
+       if(timeRunning){
+         QSystemTrayIcon::MessageIcon icon = QSystemTrayIcon::MessageIcon(3);
+         TIcon->showMessage(tr("Warning"), tr("Action imminent!"), icon, 5000);
+         showRunningProgram();
+       }
+       else{
+         QSystemTrayIcon::MessageIcon icon = QSystemTrayIcon::MessageIcon(1);
+         TIcon->showMessage(tr("Information"), tr("Countdown is not running!"), icon, 5000);
+       }
      }
 }
 
@@ -288,7 +291,7 @@ void Gui::showRunningProgram(){
 
 void Gui::keyPressEvent(QKeyEvent *kEvent){
      if(kEvent->modifiers() == Qt::ControlModifier){
-       if(!timeRunning && !lockAll){
+       if(!timeRunning && !editor->getLockAll()){
          if(kEvent->key() == Qt::Key_S){
            shutdown_action->setChecked(true);
            comboBox->setCurrentIndex(0);
@@ -306,14 +309,18 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
            comboBox->setCurrentIndex(3);
          }
        }
-       if(!lockAll){
+       if(!editor->getLockAll()){
          if(kEvent->key() == Qt::Key_E && timeRunning)
            reset();
          if(kEvent->key() == Qt::Key_L){
-           if(log_action->isChecked())
+           if(log_action->isChecked()){
              log_action->setChecked(false);
-           else
+             actionLog_file->setChecked(false);
+           }
+           else{
              log_action->setChecked(true);
+             actionLog_file->setChecked(true);
+           }
          }
          if(kEvent->key() == Qt::Key_Q)
            qApp->quit();
@@ -335,6 +342,8 @@ void Gui::updateT(){
      if(finishedExecuted)
        reset();
 
+     QDate myDate;
+
      QString tip1, tip2;
 
      if(shutdown_action->isChecked())
@@ -346,94 +355,103 @@ void Gui::updateT(){
      if(hibernate_action->isChecked())
        tip1 = (tr("hibernate in "));
 
-     if(QDate::currentDate().daysTo(setCalendarDate) >= 1)
-       toolButton->setText(setCalendarDate.toString(Qt::SystemLocaleShortDate));
-
-     if(QDate::currentDate().daysTo(setCalendarDate) > 1){ //if the date difference between today and the selected day
+     if(QDate::currentDate().daysTo(cal->setCalendarDate) > 1){ //if the date difference between today and the selected day
                                                            //in the calendar is greater than one
      //if more than one year
-       if(QDate::currentDate().daysTo(setCalendarDate) >= 365*2){
-         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)/365) + " " + tr("years"));
+       if(QDate::currentDate().daysTo(cal->setCalendarDate) > myDate.daysInYear()){
+         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInYear()) + " " + tr("years"));
          lcdL->setText(tr("years"));
-         lcd->display(QDate::currentDate().daysTo(setCalendarDate)/365);
-       }
-       if(QDate::currentDate().daysTo(setCalendarDate) >= 365 && QDate::currentDate().daysTo(setCalendarDate) < 365*2){
-         tip2 = (">= 1 " + tr("year"));
-         lcdL->setText(tr("year"));
-         lcd->display(1);
+         lcd->setNumDigits(4);
+         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInYear());
        }
      //if more than one month
-       if(QDate::currentDate().daysTo(setCalendarDate) >= 30*2 && QDate::currentDate().daysTo(setCalendarDate) < 356){
-         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)/30) + " " + tr("months"));
+       if(QDate::currentDate().daysTo(cal->setCalendarDate) > myDate.daysInMonth()
+           && QDate::currentDate().daysTo(cal->setCalendarDate) <= myDate.daysInYear()){
+         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth()) + " " + tr("months"));
          lcdL->setText(tr("months"));
-         lcd->display(QDate::currentDate().daysTo(setCalendarDate)/30);
+         if((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth() >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth());
        }
-       if(QDate::currentDate().daysTo(setCalendarDate) >= 30 && QDate::currentDate().daysTo(setCalendarDate) < 30*2){
-         tip2 = (">= 1 " + tr("month"));
-         lcdL->setText(tr("month"));
-         lcd->display(1);
-       }
-     //if less than 30 days
-       if(QDate::currentDate().daysTo(setCalendarDate) < 30){
-         tip2 = (QString::number(QDate::currentDate().daysTo(setCalendarDate)) + " " + tr("days"));
+     //if less than days in Month
+       if(QDate::currentDate().daysTo(cal->setCalendarDate) <= myDate.daysInMonth()){
+         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)) + " " + tr("days"));
          lcdL->setText(tr("days"));
-         lcd->display(QDate::currentDate().daysTo(setCalendarDate));
+         if((double)QDate::currentDate().daysTo(cal->setCalendarDate) >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate));
        }
      }
-     if(QDate::currentDate().daysTo(setCalendarDate) == 1){ //if there is one more day to go
+     if(QDate::currentDate().daysTo(cal->setCalendarDate) == 1){ //if there is one more day to go
 
        Time();
 
        if(i>=86400){ //if one day and some time to go
          tip2 = (">= 1 " + tr("day"));
          lcdL->setText(tr("day"));
-         lcd->display(1);
+         if(bigI/86400 >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display(bigI/86400);
        }
-       if(i<86400 && i>=7200){ //if there is less than one day show hours
+       if(i<86400 && i>3600){ //if there is less than one day, show hours
          tip2 = (QString::number(i/3600) + " " + tr("hours"));
          lcdL->setText(tr("hours"));
-         lcd->display(i/3600);
+         if(bigI/3600 >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display(bigI/3600);
        }
-       if(i<7200 && i>=3600){
-         tip2 = ("1 " + tr("hour"));
-         lcdL->setText(tr("hour"));
-         lcd->display(1);
-       }
-       if(i<3600 && i>=120){ //if less than one hour
+       if(i<=3600 && i>60){ //if less than one hour
          tip2 = (QString::number(i/60) + " " + tr("minutes"));
          lcdL->setText(tr("minutes"));
-         lcd->display(i/60);
+         if(bigI/60 >= 10){
+           lcd->setNumDigits(4);
+           lcd->display(bigI/60);
+         }
+         else
+           lcd->setNumDigits(3);
+         lcd->display(bigI/60);
        }
-       if(i<60){
-         tip2 = ("1 " + tr("minute"));
-         lcdL->setText(tr("minute"));
-         lcd->display(1);
+       if(i<=60){
+         tip2 = ("1 " + tr("seconds"));
+         lcdL->setText(tr("seconds"));
+         lcd->display(i);
        }
      }
-     if(QDate::currentDate()==setCalendarDate || setCalendarDate.isNull()){ //if there was no date
+     if(QDate::currentDate()==cal->setCalendarDate || cal->setCalendarDate.isNull()){ //if there was no date
                                              //set in the calendar or the set day is the current day
        Time();
 
        if(warnings->isChecked() && (((i<=100) && (i>95)) || ((i<=40) && (i>35))) && !ti->isActive())
          ti->start(30000);
 
-       if(i >= 3600){ //Display hours and minutes
+       if(i > 3600){ //Display hours and minutes
          tip2 = (QString::number(i/3600) + " " + tr("hours") + " + "
                 + QString::number(i/60 - (i/3600)*60) + " " + tr("minutes"));
          lcdL->setText(tr("hours"));
-         lcd->display(i/3600);
+         if(bigI/3600 >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display(bigI/3600);
        }
-       if(i<3600 && i>=120){ //Display only minutes
+       if(i<=3600 && i>=60){ //Display only minutes
          tip2 = (QString::number(i/60) + " " + tr("minutes"));
          lcdL->setText(tr("minutes"));
-         lcd->display(i/60);
+         if(bigI/60 >= 10)
+           lcd->setNumDigits(4);
+         else
+           lcd->setNumDigits(3);
+         lcd->display(bigI/60);
        }
-       if(i<120 && i>=60){
-         tip2 = ("1 " + tr("minute"));
-         lcdL->setText(tr("minute"));
-         lcd->display(1);
-       }
-       if(i<60){ //Display only seconds
+       if(i<=60){ //Display only seconds
          tip2 = (QString::number(i) + " " + tr("seconds"));
          lcdL->setText(tr("seconds"));
          lcd->display(i);
@@ -462,7 +480,7 @@ void Gui::set(){
        futureTime = timeEdit->time(); //else the future time is the time of the timeEdit
      n = 86400; // any number bigger than i - just for initializing
 
-     if(lock->isChecked()){       //when OK-button is clicked and lock is checked
+     if(lock->isChecked() || editor->getLockAll()){       //when OK-button is clicked and lock is checked
        QList<QWidget*> list;
        list << spin << radio1 << radio2 << lock << timeEdit << comboBox << targetTime
             << minutes;
@@ -474,63 +492,38 @@ void Gui::set(){
        minim->setFocus();
        minim->setAutoDefault(true);         //minimize-button will accept the return key
      }
-
-     if(!lockAll)
-       reset_action->setVisible(true);
+     if(!editor->getLockAll()){
+       reset_action->setEnabled(true);
+       action_Reset->setEnabled(true);
+     }
 }
 
 void Gui::Time(){
      localTime = QTime::currentTime();
      i = localTime.secsTo(futureTime); //the difference of the localTime and the future time
-     if(radio2->isChecked() && (QDate::currentDate().daysTo(setCalendarDate) == 1))
+     if(radio2->isChecked() && (QDate::currentDate().daysTo(cal->setCalendarDate) == 1))
        i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + spin->value()*60);
-     if(radio1->isChecked() && (QDate::currentDate().daysTo(setCalendarDate) == 1))
+     if(radio1->isChecked() && (QDate::currentDate().daysTo(cal->setCalendarDate) == 1))
        i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + timeEdit->time().hour()*3600
            + timeEdit->time().minute()*60);
      if(i<0)                           //if the date is on the next day
        i += 86400; //add 1 day in seconds
+     bigI = i; //for more precise display with LCD
 }
 
 void Gui::saveWindowSize(){
    #ifdef Q_OS_WIN32
      QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::NativeFormat);
    #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::NativeFormat);
    #endif //Q_OS_WIN32
-     settings.setValue("MainWindowSize/size", size());
+     QSettings settings(file, QSettings::NativeFormat);
+
+     settings.setValue("MainWindow/size", size());
+     settings.setValue("MainWindow/keep_proportions", actionKeep_window_proportions->isChecked());
 }
 
-void Gui::finished_(){
-     finishedExecuted = true;
-     switch(comboBox->currentIndex()){
-       case 0:
-         saveWindowSize();
-         Power::shutdown();
-         break;
-       case 1:
-         saveWindowSize();
-         Power::reboot();
-         break;
-       case 2:
-         Power::suspend();
-         break;
-       case 3:
-         Power::hibernate();
-         break;
-       default:;
-     }
-     qApp->quit();
-}
-
-void Gui::closeEvent(QCloseEvent* window_close){
-     hide();
-     minimize_restore_action->setText(minimize);
-     QWidget::closeEvent(window_close);
-}
-
-void Gui::beforeQuit(){
+void Gui::saveLog(){
      saveWindowSize();
      if(log_action->isChecked()){ //if logfile is set in the icon contextmenu
      #ifdef Q_OS_WIN32
@@ -569,7 +562,45 @@ void Gui::beforeQuit(){
            isBigger = false;
        }
      }
+}
 
+void Gui::finished_(){
+     finishedExecuted = true;
+     saveLog();
+     switch(comboBox->currentIndex()){
+       case 0:
+         saveWindowSize();
+         Power::shutdown();
+         break;
+       case 1:
+         saveWindowSize();
+         Power::reboot();
+         break;
+       case 2:
+         if(pref->lockMyScreen){ Power::lockMyScreen = true; }
+         Power::suspend();
+         break;
+       case 3:
+         if(pref->lockMyScreen){ Power::lockMyScreen = true; }
+         Power::hibernate();
+         break;
+       default:;
+     }
+}
+
+void Gui::closeEvent(QCloseEvent* window_close){
+     if(!pref->getQuitOnClose()){
+       hide();
+       minimize_restore_action->setText(minimize);
+     }
+     else if(!editor->getLockAll())
+       qApp->quit();
+     QWidget::closeEvent(window_close);
+}
+
+void Gui::beforeQuit(){
+     if(!finishedExecuted)
+       saveLog();
   #ifndef Q_OS_WIN32
      QDBusConnection::sessionBus().unregisterObject(OBJECT_NAME, QDBusConnection::UnregisterNode);
      QDBusConnection::sessionBus().unregisterService(SERVICE_NAME);
@@ -580,16 +611,18 @@ void Gui::loadSettings(){
 /***************** create file and it's entries *****************/
 #ifdef Q_OS_WIN32
      QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::NativeFormat);
 #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::NativeFormat);
 #endif //Q_OS_WIN32
+     QSettings settings(file, QSettings::NativeFormat);
+
      if(!settings.isWritable())
        qCritical() << "W: qshutdown.conf is not writable!";
 
      if(!QFile::exists(file) || !settings.contains("Lock_all"))
        settings.setValue("Lock_all", false);
+     if(!settings.contains("Quit_on_close"))
+       settings.setValue("Quit_on_close", false);
      if(!settings.contains("Time/time_hour"))
        settings.setValue("Time/time_hour", 22);
      if(!settings.contains("Time/time_minute"))
@@ -600,8 +633,10 @@ void Gui::loadSettings(){
        settings.setValue("Time/countdown_at_startup", false);
      if(!settings.contains("Hide_at_startup"))
        settings.setValue("Hide_at_startup", false);
-     if(!settings.contains("MainWindowSize/size"))
-       settings.setValue("MainWindowSize/size", QSize(350, 310));
+     if(!settings.contains("MainWindow/size"))
+       settings.setValue("MainWindow/size", QSize(290, 280));
+     if(!settings.contains("MainWindow/keep_proportions"))
+       settings.setValue("MainWindow/keep_proportions", false);
      if(!settings.contains("Fonts/font_type"))
        settings.setValue("Fonts/font_type", "Times New Roman");
      if(!settings.contains("Fonts/font1"))
@@ -632,13 +667,19 @@ void Gui::loadSettings(){
 /***************** read files entries *****************/
      timeEdit->setTime(QTime(settings.value("Time/time_hour").toInt(),settings.value("Time/time_minute").toInt()));
      spin->setValue(settings.value("Time/countdown_minutes").toInt());
-     resize(settings.value("MainWindowSize/size").toSize());
-     font1->setFamily(settings.value("Fonts/font_type").toString());
-     font2->setFamily(settings.value("Fonts/font_type").toString());
-     font3->setFamily(settings.value("Fonts/font_type").toString());
-     font1->setPointSize(settings.value("Fonts/font1").toInt());
-     font2->setPointSize(settings.value("Fonts/font2").toInt());
-     font3->setPointSize(settings.value("Fonts/font3").toInt());
+     resize(settings.value("MainWindow/size").toSize());
+     actionKeep_window_proportions->setChecked(settings.value("MainWindow/keep_proportions").toBool());
+     if(settings.contains("Fonts/font_type")){
+       font1->setFamily(settings.value("Fonts/font_type").toString());
+       font2->setFamily(settings.value("Fonts/font_type").toString());
+       font3->setFamily(settings.value("Fonts/font_type").toString());
+       font1->setPointSize(settings.value("Fonts/font1").toInt());
+       font2->setPointSize(settings.value("Fonts/font2").toInt());
+       font3->setPointSize(settings.value("Fonts/font3").toInt());
+     }
+     else
+       getFonts();
+
      radio1->setChecked(settings.value("CheckBoxes/target_time").toBool());
      radio2->setChecked(settings.value("CheckBoxes/countdown").toBool());
      lock->setChecked(settings.value("CheckBoxes/lock").toBool());
@@ -655,12 +696,7 @@ void Gui::loadSettings(){
        }
      }
 
-     if(settings.value("Lock_all").toBool()){
-       lockAll = true;
-       lockEverything(true);
-     }
-     else
-       lockAll = false;
+     lockEverything(settings.value("Lock_all").toBool());
 
      QList<QWidget*> list;
      list << lcdL << comboBox << targetTime
@@ -672,6 +708,7 @@ void Gui::loadSettings(){
      warnings->setFont(*font3);
      lock->setFont(*font3);
      now->setFont(*font3);
+     toolButton->setFont(*font3);
 
      switch(settings.value("Power/comboBox").toInt()){
        case 0:
@@ -696,58 +733,61 @@ void Gui::loadSettings(){
          break;
        default:;
      }
-
-     if(settings.value("Lock_screen").toBool())
-       lockMyScreen = true;
-     else
-       lockMyScreen = false;
 }
 
 void Gui::lockEverything(bool actual){
-     if(timeRunning){
-       reset_action->setVisible(true);
-       reset_action->setDisabled(actual);
-       quit_action->setDisabled(actual);
-       log_action->setDisabled(actual);
-       toolButton->setDisabled(actual);
-     }
-     else if(!timeRunning){
-       if(actual)
-         lock->setChecked(true);
-       if(radio1->isChecked())
-         timeEdit->setDisabled(actual);
-       else
-         spin->setDisabled(actual);
-       reset_action->setDisabled(actual);
-       quit_action->setDisabled(actual);
-       log_action->setDisabled(actual);
-       power_actions->setDisabled(actual);
-       reset_action->setVisible(false);
-       QList<QWidget*> widgetList;
-       widgetList << radio1 << radio2 << lock << comboBox << targetTime
-                  << minutes << toolButton;
-       foreach(QWidget * widgetPtr, widgetList)
-         widgetPtr->setDisabled(actual);
-     }
+     if(radio1->isChecked())
+       timeEdit->setDisabled(actual);
+     else
+       spin->setDisabled(actual);
+
+     quit_action->setDisabled(actual);
+     actionQuit->setDisabled(actual);
+     log_action->setDisabled(actual);
+     actionLog_file->setDisabled(actual);
+     power_actions->setDisabled(actual);
+
      QList<QWidget*> widgetList;
-     widgetList << pref->comboBox << pref->timeEdit << pref->spin
-                << pref->radio1 << pref->radio2
+     widgetList << radio1 << radio2 << lock << comboBox << targetTime
+                << minutes << pref->comboBox << pref->timeEdit << pref->spin
+                << pref->radio1 << pref->radio2 << pref->stopHide
                 << pref->autostart << pref->lock << pref->countdown
-                << pref->log << pref->reset;
+                << pref->log << pref->reset << pref->spinBox;
      foreach(QWidget * widgetPtr, widgetList)
        widgetPtr->setDisabled(actual);
-     if(pref->log->isEnabled() && pref->log->isChecked())
-       pref->spinBox->setDisabled(false);
-     else
-       pref->spinBox->setDisabled(true);
+
+     if(lock->isChecked() && timeRunning && !actual){
+       timeEdit->setDisabled(true);
+       radio1->setDisabled(true);
+       spin->setDisabled(true);
+       radio2->setDisabled(true);
+       comboBox->setDisabled(true);
+       targetTime->setDisabled(true);
+       minutes->setDisabled(true);
+     }
+     if(timeRunning){
+       reset_action->setDisabled(actual);
+       action_Reset->setDisabled(actual);
+       if(!lock->isChecked()){
+         ok->hide();
+         minim->show();
+         minim->setFocus();
+         minim->setAutoDefault(true);
+       }
+     }
+     else{
+       reset_action->setDisabled(true);
+       action_Reset->setDisabled(true);
+     }
 }
 void Gui::reset(){
      setWindowTitle("'qshutdown'");
-     toolButton->setText("...");
+     toolButton->setText("Calendar");
      lcd->display(0);
      TIcon->setToolTip(NULL);
      lcdL->setText(tr("minutes"));
-     setCalendarDate = QDate();
+     cal->setCalendarDate = QDate();
+     cal->calendarDate = QDate();
      if(finishedExecuted)
        showNormal();
      timer->stop();
@@ -757,18 +797,20 @@ void Gui::reset(){
      finishedExecuted = false;
      minim->hide();
      ok->show();
-     if(!lockAll)
+     if(!editor->getLockAll())
        lockEverything(false);
      else loadSettings();
+     action_Reset->setDisabled(true);
+     reset_action->setDisabled(true);
 }
 
 void Gui::getFonts(){
-     font1->setFamily(fonts);
-     font1->setPointSize(fontS1);
-     font2->setFamily(fonts);
-     font2->setPointSize(fontS2);
-     font3->setFamily(fonts);
-     font3->setPointSize(fontS3);
+     font1->setFamily(pref->fonts);
+     font1->setPointSize(pref->fontS1);
+     font2->setFamily(pref->fonts);
+     font2->setPointSize(pref->fontS2);
+     font3->setFamily(pref->fonts);
+     font3->setPointSize(pref->fontS3);
 
      QList<QWidget*> list;
      list << lcdL << comboBox << targetTime
@@ -780,37 +822,33 @@ void Gui::getFonts(){
      warnings->setFont(*font3);
      lock->setFont(*font3);
      now->setFont(*font3);
-
-     resize(minimumSize());
+     toolButton->setFont(*font3);
 }
 
 void Gui::showCalendarBox(){
-     if(setCalendarDate.isNull())
-       calendarBox->calendarWidget->setSelectedDate(QDate::currentDate());
+     if(cal->setCalendarDate.isNull())
+       cal->calendarWidget->setSelectedDate(QDate::currentDate());
      else
-       calendarBox->calendarWidget->setSelectedDate(setCalendarDate);
-     if(timeRunning && lock->isChecked())
-       calendarBox->calendarWidget->blockSignals(true);
+       cal->calendarWidget->setSelectedDate(cal->setCalendarDate);
+     if(editor->getLockAll() || (timeRunning && lock->isChecked()))
+       cal->calendarWidget->blockSignals(true);
      else
-       calendarBox->calendarWidget->blockSignals(false);
-     calendarBox->show();
+       cal->calendarWidget->blockSignals(false);
+     cal->show();
 }
 
 void Gui::updateLock(){
-   #ifdef Q_OS_WIN32
-     QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-   #else //!Q_OS_WIN32
-     QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
-   #endif //Q_OS_WIN32
-     QSettings settings(file, QSettings::NativeFormat);
-     if(settings.value("Lock_all").toBool()){
-       lockAll = true;
+     if(editor->getLockAll())
        lockEverything(true);
-     }
-     else{
-       lockAll = false;
+     else
        lockEverything(false);
-     }
 }
 
 void Gui::showEditor(){ QTimer::singleShot(250, editor, SLOT(show())); } //using singleShot because of focus problems...
+
+void Gui::staticProportions(bool var){
+     if(var)
+       frame->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+     else
+       frame->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
+}
