@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 
 #include "info.h"
 
-extern bool infoClosed;  //varibale declared in gui.cpp
-extern bool timeRunning; // ""
-
 Info::Info(QWidget *parent): QTextEdit(parent){
-     setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
+
+     isClosed = true;
+
+     setWindowFlags(Qt::Window);
      setReadOnly(true);
      resize(500,450);
      setWindowTitle(tr("Info"));
@@ -30,15 +30,15 @@ Info::Info(QWidget *parent): QTextEdit(parent){
 Info::~Info(){ }
 
 void Info::showEvent(QShowEvent* show_){
-     infoClosed = false;
+     isClosed = false;
      starting();
      QTextEdit::showEvent(show_);
 }
 
 void Info::closeEvent(QCloseEvent* close_){
-     if(!timeRunning){
-       infoClosed = true;
-       finishing();
-     }
+     isClosed = true;
+     finishing();
      QTextEdit::closeEvent(close_);
 }
+
+bool Info::getClosed(){ return isClosed; }
