@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #ifndef INFO_H
 #define INFO_H
 
-#include <QtGui>
+#include <QTextEdit>
 
 class Info : public QTextEdit{
      Q_OBJECT
@@ -25,6 +25,10 @@ class Info : public QTextEdit{
     public:
      Info(QWidget *parent = 0);
      ~Info();
+     bool getClosed();
+
+    private:
+     bool isClosed;
 
     signals:
      void starting();
