@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +15,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "gui.h"
-#include <QApplication>
+#include <QTranslator>
+#include <QLibraryInfo>
 
-bool verbose; //this is a global variable needed in power.cpp
+/// test comment for git testing
+
+bool verbose = false; //this is a global variable needed in power.cpp
 
 int main(int argc, char *argv[]){
 
@@ -57,9 +60,8 @@ int main(int argc, char *argv[]){
        "need to add the following line to the sudoers (as above):"
        "<pre>* ALL = NOPASSWD:/usr/bin/qshutdown</pre><br/>If you should ever forget "
        "your set password, just remove the whole line starting with \"Password\" manually from "
-       "the qshutdown.conf.<br/><br/><b>Hints on usage:</b><br/>One can not close qshutdown, but "
-       "only quit it using the sytem tray icon (indicator) or the key combination Ctrl+Q "
-       "(see hotkeys).<br/>If you want qshutdown to stop \"bugging\" you, just remove the hook from "
+       "the qshutdown.conf.<br/><br/><b>Hints on usage:</b><br/>If you want qshutdown to stop "
+       "\"bugging\" you, just remove the hook from "
        "\"warnings on?\".<br/><br/><b>Hotkeys:</b><table border=\"1\"><tr><td>Ctrl+I</td><td>(this)"
        " information window</td></tr><tr><td>Ctrl+Q</td><td>Quit</td></tr><tr><td>Ctrl+P</td>"
        "<td>Prefereces</td></tr><tr><td>Ctrl+L</td><td>write the run time once into the logfile (works "
@@ -82,15 +84,15 @@ int main(int argc, char *argv[]){
        QString arg = args[0];
        if(arg[0] == '-'){
          if(arg.contains("h") || args.contains("--help"))
-           qDebug() << "\nqshutdown [ options ... ]\n\nOptions are:\n\t-h "
+           qDebug("\nqshutdown [ options ... ]\n\nOptions are:\n\t-h "
                        "or --help\tPrints this message.\n\t-i\t\tPrints "
-                       "information.\n\t-v\t\tPrints all errors and warnings.\n";
+                       "information.\n\t-v\t\tPrints all errors and warnings.\n");
          if(arg.contains("i"))
-           qDebug() << info.toAscii().data();
+           qDebug(info.toAscii().data());
        }
        if(!((arg[0] == '-') && (arg.contains("h") || args.contains("--help")
           || arg.contains("i") || arg.contains("-v"))))
-         qDebug() << " Wrong options! Try qshutdown -h";
+         qDebug(" Wrong options! Try qshutdown -h");
        if(args.first() == "-v")
          verbose = true;
      }
