@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,9 @@
 #ifndef PASSWD_H
 #define PASSWD_H
 
-#include <QtGui>
 #include "ui_passwd.h"
+#include <QMessageBox>
+#include <QSettings>
 
 class ChangePassword;
 
@@ -28,6 +29,7 @@ class PassWord : public QDialog, public Ui::PassWord {
     public:
      PassWord(QWidget *parent = 0);
      ~PassWord();
+     bool getClosed();
 
     signals:
      void success();
@@ -39,6 +41,7 @@ class PassWord : public QDialog, public Ui::PassWord {
      QString        file;
      QMessageBox    *msgBox;
      ChangePassword *chPW;
+     bool           isClosed;
 
     private slots:
      void checkPW();
