@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,9 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
-#include <QtGui>
 #include "ui_preferences.h"
+#include <QSettings>
+#include <QMessageBox>
 
 class Preferences : public QDialog, public Ui::Preferences {
      Q_OBJECT
@@ -26,8 +27,14 @@ class Preferences : public QDialog, public Ui::Preferences {
     public:
      Preferences(QWidget *parent = 0);
      ~Preferences();
+     QString fonts;
+     int fontS1, fontS2, fontS3;
+     bool getClosed();
+     bool getQuitOnClose();
+     bool lockMyScreen;
 
     private:
+     bool        isClosed;
      QString     file;
      QSettings   *settings;
      QMessageBox *msgBox;
@@ -41,8 +48,8 @@ class Preferences : public QDialog, public Ui::Preferences {
      void fontSize1Changed(int f1);
      void fontSize2Changed(int f2);
      void fontSize3Changed(int f3);
-     void lockScreen();
      void autostartFile();
+     void lockScreen();
 
     signals:
      void starting();
